@@ -27,6 +27,7 @@ class Specs(SpecSet):
     aws_instance_id_doc = RegistryPoint()
     aws_instance_id_pkcs7 = RegistryPoint()
     aws_instance_type = RegistryPoint()
+    awx_manage_check_license = RegistryPoint()
     azure_instance_type = RegistryPoint()
     bios_uuid = RegistryPoint()
     blkid = RegistryPoint()
@@ -105,6 +106,7 @@ class Specs(SpecSet):
     date_iso = RegistryPoint()
     date = RegistryPoint()
     date_utc = RegistryPoint()
+    designate_conf = RegistryPoint(filterable=True)
     dcbtool_gc_dcb = RegistryPoint(multi_output=True)
     df__alP = RegistryPoint()
     df__al = RegistryPoint()
@@ -118,6 +120,7 @@ class Specs(SpecSet):
     dirsrv_errors = RegistryPoint(multi_output=True, filterable=True)
     display_java = RegistryPoint()
     display_name = RegistryPoint()
+    dm_mod_use_blk_mq = RegistryPoint()
     dmesg = RegistryPoint(filterable=True)
     dmesg_log = RegistryPoint(filterable=True)
     dmidecode = RegistryPoint()
@@ -246,6 +249,7 @@ class Specs(SpecSet):
     ip_netns_exec_namespace_lsof = RegistryPoint(multi_output=True, filterable=True)
     ip_route_show_table_all = RegistryPoint()
     ip_s_link = RegistryPoint()
+    ipsec_conf = RegistryPoint(filterable=True)
     iptables_permanent = RegistryPoint()
     iptables = RegistryPoint()
     ipv4_neigh = RegistryPoint()
@@ -276,6 +280,8 @@ class Specs(SpecSet):
     lastupload = RegistryPoint(multi_output=True)
     libkeyutils_objdumps = RegistryPoint()
     libkeyutils = RegistryPoint()
+    libssh_client_config = RegistryPoint(filterable=True)
+    libssh_server_config = RegistryPoint(filterable=True)
     libvirtd_log = RegistryPoint(filterable=True)
     libvirtd_qemu_log = RegistryPoint(multi_output=True, filterable=True)
     limits_conf = RegistryPoint(multi_output=True)
@@ -543,6 +549,7 @@ class Specs(SpecSet):
     scheduler = RegistryPoint(multi_output=True)
     sched_rt_runtime_us = RegistryPoint()
     scsi = RegistryPoint()
+    scsi_mod_use_blk_mq = RegistryPoint()
     sctp_asc = RegistryPoint()
     sctp_eps = RegistryPoint()
     sctp_snmp = RegistryPoint()
@@ -560,6 +567,7 @@ class Specs(SpecSet):
     sockstat = RegistryPoint()
     softnet_stat = RegistryPoint()
     software_collections_list = RegistryPoint()
+    spamassassin_channels = RegistryPoint()
     spfile_ora = RegistryPoint(multi_output=True)
     ssh_config_d = RegistryPoint(multi_output=True, filterable=True)
     ssh_config = RegistryPoint(filterable=True)
@@ -675,3 +683,5 @@ class Specs(SpecSet):
     yum_repos_d = RegistryPoint(multi_output=True)
     zdump_v = RegistryPoint()
     zipl_conf = RegistryPoint()
+    sendq_socket_buffer = RegistryPoint()
+    recvq_socket_buffer = RegistryPoint()
